/**
 * The next sketch is a part of a bigger project related to dressing
 * The setup is described in the instructable and it should activate clothes recommendations according to the weather, and allow you 
 * to fold the unwanted clothes!
 * In order to fold the unwanted clothes the CPX should be attached to 3 Servos, that should be attached to a laundry folder. The servos
 * should be calibrated accordingly before being attached. If all the servos are connected to the CPX, the CPX should be empowered using
 * a powerful source.
 * All the variable declarations are in Dresser.h and pin configuration are in BlynkConfig.h
 * 
 * The circuit: Circuit Playground Express + ESP8266 + 3 x Servos attached to CPX using alligator cables and jumper cables
 * 
 * Created By:
 * Idan Kringel
 * Ori Blanka
 * David German
 */

#include "Dresser.h"
#include "BlynkConfig.h"

void setup() { 
  Serial.begin(9600);
  delay(10);
  SerialUSB.begin(9600);
  delay(10);
  EspSerial.begin(ESP_BAUD);
  delay(10);
  Blynk.begin(auth, wifi, ssid, pass);
  delay(10);
  servo_left.attach(SERVO_LEFT_PIN);
  servo_right.attach(SERVO_RIGHT_PIN); 
  servo_top.attach(SERVO_TOP_PIN);
  //fold 1 time to calibrate servos
  fold();
  
}

void loop() {
  Blynk.run();
  update_temperature();

}
// updates the temperature gauge and triggers integromat weather scenario
void update_temperature(){
  if((millis() - last_temperature_update) >  TEMPERATURE_UPDATE_INTERVAL) {
    float temperature = CircuitPlayground.temperature();
    Serial.println(temperature);
    Blynk.virtualWrite(TEMPERATURE_READ_PIN, temperature);
    last_temperature_update = millis();
    Blynk.virtualWrite(TEMPERATURE_WEBHOOK_PIN, device_lat, device_long);
  }
}

void fold(){
  servo_left.write(180);
  delay(2000);
  servo_left.write(0);
  delay(2000);
  servo_right.write(0);
  delay(2000);
  servo_right.write(180);
  delay(2000);
  servo_top.write(180);
  delay(2000);
  servo_top.write(0);
  delay(2000);
}

BLYNK_WRITE(GPS_PIN) {
  GpsParam gps(param);
  device_lat = gps.getLat();
  device_long = gps.getLon();
}

BLYNK_WRITE(FOLD_PIN){
  fold(); 
}
